==> winnie-0.1.46.tgz: package/properties/winnie-property.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');
var Bound = require('kenga/bound');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);
var Bound__default = /*#__PURE__*/_interopDefaultLegacy(Bound);

var WinnieProperty = /*#__PURE__*/function () {
  function WinnieProperty(wWrapper, name, onChange, defaultValue) {
    _classCallCheck__default['default'](this, WinnieProperty);

    this.target = wWrapper.delegate;
    var selects = wWrapper.source.selects;
    this.options = selects[name] ? selects[name] : null;
    this.name = name;
    this.onChange = onChange;
    this.defaultValue = defaultValue;

    if (name === 'visible') {
      this.visible = this.target.visible; //this.target.visible = true;
    }
  }

  _createClass__default['default'](WinnieProperty, [{
    key: "value",
    get: function get() {
      return this.name === 'visible' ? this.visible : this.name.includes('.') ? Bound__default['default'].getPathData(this.target, this.name) : this.target[this.name];
    },
    set: function set(newValue) {
      var oldValue = this.value;

      if (oldValue != newValue) {
        // Warning! Don't edit as !== .
        this.onChange(newValue);
      }
    }
  }, {
    key: "edited",
    get: function get() {
      return this.value != this.defaultValue; // Warning! Don't edit as !== .
    }
  }]);

  return WinnieProperty;
}();

module.exports = WinnieProperty;

==> winnie-0.1.55.tgz: package/properties/winnie-property.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');
var Bound = require('kenga/bound');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);
var Bound__default = /*#__PURE__*/_interopDefaultLegacy(Bound);

var WinnieProperty = /*#__PURE__*/function () {
  function WinnieProperty(wWrapper, name, onChange, defaultValue) {
    _classCallCheck__default["default"](this, WinnieProperty);

    this.target = wWrapper.delegate;
    var selects = wWrapper.source.selects;
    this.options = selects[name] ? selects[name] : null;
    this.name = name;
    this.onChange = onChange;
    this.defaultValue = defaultValue;

    if (name === 'visible') {
      this.visible = this.target.visible;
      this.target.visible = true;
    }
  }

  _createClass__default["default"](WinnieProperty, [{
    key: "value",
    get: function get() {
      return this.name === 'visible' ? this.visible : this.name.includes('.') ? Bound__default["default"].getPathData(this.target, this.name) : this.target[this.name];
    },
    set: function set(newValue) {
      var oldValue = this.value;

      if (oldValue != newValue) {
        // Warning! Don't edit as !== .
        this.onChange(newValue);
      }
    }
  }, {
    key: "edited",
    get: function get() {
      return this.value != this.defaultValue; // Warning! Don't edit as !== .
    }
  }]);

  return WinnieProperty;
}();

module.exports = WinnieProperty;
